package com.javaproxy;

import java.io.File;
import java.io.IOException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

/* loaded from: com_javaproxy.jar:com/javaproxy/XmlManifestReader.class */
class XmlManifestReader {
    public static final String DEFAULT_XML = "AndroidManifest.xml";
    private static final float[] RADIX_MULTS = {0.00390625f, 3.051758E-5f, 1.192093E-7f, 4.656613E-10f};
    private static final String[] DIMENSION_UNITS = {"px", "dip", "sp", "pt", "in", "mm", "", ""};
    private static final String[] FRACTION_UNITS = {"%", "%p", "", "", "", "", "", ""};

    private XmlManifestReader() {
    }

    public static String getManifestXMLFromAPK(String apkPath) {
        ZipFile file = null;
        String rs = null;
        try {
            try {
                File apkFile = new File(apkPath);
                file = new ZipFile(apkFile, 1);
                ZipEntry entry = file.getEntry(DEFAULT_XML);
                rs = getManifestXMLFromAPK(file, entry);
                if (file != null) {
                    try {
                        file.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            } catch (Throwable th) {
                if (file != null) {
                    try {
                        file.close();
                    } catch (IOException e2) {
                        e2.printStackTrace();
                    }
                }
                throw th;
            }
        } catch (Exception e3) {
            e3.printStackTrace();
            if (file != null) {
                try {
                    file.close();
                } catch (IOException e4) {
                    e4.printStackTrace();
                }
            }
        }
        return rs;
    }

    public static String getManifestXMLFromAPK(ZipFile file, ZipEntry entry) {
        StringBuilder sb;
        StringBuilder xmlSb = new StringBuilder(100);
        XmlResourceParser parser = null;
        try {
            try {
                parser = new XmlResourceParser();
                parser.open(file.getInputStream(entry));
                sb = new StringBuilder(10);
            } catch (Exception e) {
                e.printStackTrace();
                parser.close();
            }
            while (true) {
                int type = parser.next();
                if (type != 1) {
                    switch (type) {
                        case 0:
                            log(xmlSb, "<?xml version=\"1.0\" encoding=\"utf-8\"?>", new Object[0]);
                            break;
                        case 2:
                            log(false, xmlSb, "%s<%s%s", sb, getNamespacePrefix(parser.getPrefix()), parser.getName());
                            sb.append("\t");
                            int namespaceCountBefore = parser.getNamespaceCount(parser.getDepth() - 1);
                            int namespaceCount = parser.getNamespaceCount(parser.getDepth());
                            int i = namespaceCountBefore;
                            while (i != namespaceCount) {
                                Object[] objArr = new Object[3];
                                objArr[0] = i == namespaceCountBefore ? "  " : sb;
                                objArr[1] = parser.getNamespacePrefix(i);
                                objArr[2] = parser.getNamespaceUri(i);
                                log(xmlSb, "%sxmlns:%s=\"%s\"", objArr);
                                i++;
                            }
                            int size = parser.getAttributeCount();
                            for (int i2 = 0; i2 != size; i2++) {
                                log(false, xmlSb, "%s%s%s=\"%s\"", " ", getNamespacePrefix(parser.getAttributePrefix(i2)), parser.getAttributeName(i2), getAttributeValue(parser, i2));
                            }
                            log(xmlSb, ">", new Object[0]);
                            break;
                        case 3:
                            sb.setLength(sb.length() - "\t".length());
                            log(xmlSb, "%s</%s%s>", sb, getNamespacePrefix(parser.getPrefix()), parser.getName());
                            break;
                        case 4:
                            log(xmlSb, "%s%s", sb, parser.getText());
                            break;
                    }
                } else {
                    parser.close();
                    return xmlSb.toString();
                }
            }
        } catch (Throwable th) {
            parser.close();
            throw th;
        }
    }

    private static String getNamespacePrefix(String prefix) {
        if (prefix == null || prefix.length() == 0) {
            return "";
        }
        return String.valueOf(prefix) + ":";
    }

    private static String getAttributeValue(XmlResourceParser parser, int index) {
        int type = parser.getAttributeValueType(index);
        int data = parser.getAttributeValueData(index);
        if (type == 3) {
            return parser.getAttributeValue(index);
        }
        if (type == 2) {
            return String.format("?%s%08X", getPackage(data), Integer.valueOf(data));
        }
        if (type == 1) {
            return String.format("@%s%08X", getPackage(data), Integer.valueOf(data));
        }
        if (type == 4) {
            return String.valueOf(Float.intBitsToFloat(data));
        }
        if (type == 17) {
            return String.format("0x%08X", Integer.valueOf(data));
        }
        if (type == 18) {
            return data != 0 ? "true" : "false";
        }
        if (type == 5) {
            return String.valueOf(Float.toString(complexToFloat(data))) + DIMENSION_UNITS[data & 15];
        }
        if (type == 6) {
            return String.valueOf(Float.toString(complexToFloat(data))) + FRACTION_UNITS[data & 15];
        }
        if (type >= 28 && type <= 31) {
            return String.format("#%08X", Integer.valueOf(data));
        }
        if (type >= 16 && type <= 31) {
            return String.valueOf(data);
        }
        return String.format("<0x%X, type 0x%02X>", Integer.valueOf(data), Integer.valueOf(type));
    }

    private static String getPackage(int id) {
        if ((id >>> 24) == 1) {
            return "android:";
        }
        return "";
    }

    private static void log(StringBuilder xmlSb, String format, Object... arguments) {
        log(true, xmlSb, format, arguments);
    }

    private static void log(boolean newLine, StringBuilder xmlSb, String format, Object... arguments) {
        xmlSb.append(String.format(format, arguments));
        if (newLine) {
            xmlSb.append("\n");
        }
    }

    private static float complexToFloat(int complex) {
        return (complex & (-256)) * RADIX_MULTS[(complex >> 4) & 3];
    }
}
